
"""
.. module:: raytracing_main.py
    :synopsis: It contains the main function that creates a window and
     displays the scene.
.. moduleauthor:: Kereman Alonso (alonso.kerman5@gmail.com)
"""


import tkinter as tk
import time
from PIL import ImageTk, Image

import modules.scene as scene


def get_image(scene_file):

    t0 = time.perf_counter()

    objects, lights, camera, ambient, air =\
        scene.scene_parser(scene_file)

    pixel_data = scene.render(objects, lights, camera, ambient, air)

    # convert pixel_data matrix into a .png image
    rendered_image = Image.fromarray(pixel_data)

    # create window and set title
    window = tk.Tk()
    window.title("TFG IE")

    # create frame inside window
    image_frame = tk.LabelFrame(window)
    image_frame.pack(padx=10, pady=10)

    # convert renderer_image into a tk compatible image and prepare to
    # display in image_frame
    image_tk = ImageTk.PhotoImage(rendered_image)
    label = tk.Label(image_frame, image=image_tk)
    label.pack()

    rendered_image.save('..\\inputs_outputs\\outputs\\render.png')
    print("Total execution time:")
    print("--- {} seconds ---".format(time.perf_counter() - t0))

    window.mainloop()


if __name__ == "__main__":

    scene_file = '..\\inputs_outputs\\scenes\\standard_scene_table.txt'
    get_image(scene_file)
